install_eval_context

Function install_eval_context 

pub fn install_eval_context(globals: Arc<GlobalEnv>, ns: Arc<str>)
Install a previously captured eval context on the current thread.

Call this at the start of a spawned thread so that invoke works.